@@ -6,6 +6,8 @@ from plone.i18n.normalizer import IIDNormalizer
 from plone.memoize import ram
 from plone.memoize.instance import Memojito
 from plone.memoize.interfaces import ICacheChooser
+from Products.CMFPlone.utils import base_hasattr
+from types import FunctionType
 from zope.component import getAllUtilitiesRegisteredFor
 from zope.component import getUtility
 from zope.component import queryUtility
@@ -158,3 +160,24 @@ def volatile_cache_without_parameters(func):
     replacement = cache(get_key)(func)
     replacement._cache_key = generate_key(func)
     return replacement
+
+
+def obj_modified(obj, asdatetime=True, check_annotation=True, asstring=False):
+    """Returns max value between obj.modified(), obj._p_mtime and __anotations__._p_mtime.
+
+       to check also attribute modification and annotation modification."""
+    if check_annotation and base_hasattr(obj, '__annotations__'):
+        modified = max(float(obj.modified()), obj._p_mtime, obj.__annotations__._p_mtime)
+    else:
+        modified = max(float(obj.modified()), obj._p_mtime)
+    if asdatetime:
+        modified = datetime.fromtimestamp(modified)
+    elif asstring:
+        modified = datetime.fromtimestamp(modified).strftime('%Y%m%d-%H%M%S-%f')
+    return modified
+
+
+def extract_wrapped(decorated):
+    """Returns function that was decorated"""
+    closure = (c.cell_contents for c in decorated.__closure__)
+    return next((c for c in closure if isinstance(c, FunctionType)), None)
