@@ -601,6 +601,12 @@ def safe_delattr(obj, attr_name):
         delattr(obj, attr_name)
 
 
+def base_getattr(obj, attr_name, default=None):
+    """ """
+    if base_hasattr(obj, attr_name):
+        return getattr(obj, attr_name, default)
+
+
 def get_relations(obj, attribute=None, backrefs=False):
     """Get any kind of references and backreferences"""
     res = []
@@ -706,3 +712,11 @@ def get_user_fullname(username):
                 fullname = data._identities['authentic-agents'].data['fullname']
             return fullname or username
     return username
+
+
+def get_transitions(obj):
+    """Return the ids of the available transitions as portal_workflow.getTransitionsFor
+       will actually return a list of dict with various infos (id, title, name, ...) of
+       the available transitions."""
+    wfTool = api.portal.get_tool('portal_workflow')
+    return [tr["id"] for tr in wfTool.getTransitionsFor(obj)]
