@@ -87,6 +87,52 @@ def removeBlanks(xhtmlContent, pretty_print=False):
                     for x in tree.iterchildren()])
 
 
+def replace_content(xhtml_content,
+                    css_class,
+                    new_content=u"",
+                    new_content_link={},
+                    pretty_print=False):
+    '''This method will get tags using given p_css_class and
+       replace it's content with given p_content.'''
+    tree = _turnToLxmlTree(xhtml_content)
+    if not isinstance(tree, lxml.html.HtmlElement):
+        return xhtml_content
+
+    new_content = safe_unicode(new_content)
+
+    from lxml.cssselect import CSSSelector
+    selector = CSSSelector('.' + css_class)
+    elements = selector(tree)
+    for main_elt in elements:
+        # will find every contained elements
+        # store itered elements as we add new elements,
+        # iteration ignores last elements
+        elts = [elt for elt in main_elt.iter()]
+        for elt in elts:
+            is_main_elt = elt == main_elt
+            if is_main_elt:
+                if new_content_link:
+                    elt.text = u""
+                    new_elt = lxml.html.Element("a")
+                    new_elt.attrib["href"] = new_content_link["href"]
+                    new_elt.attrib["title"] = new_content_link.get("title", u"")
+                    new_elt.text = new_content or u""
+                    elt.append(new_elt)
+                else:
+                    elt.text = new_content or u""
+            else:
+                elt.tag = "span"
+                elt.text = u""
+                elt.tail = u""
+
+    # only return children of the <special_tag>
+    return ''.join([lxml.html.tostring(x,
+                                       encoding='ascii',
+                                       pretty_print=pretty_print,
+                                       method='html')
+                    for x in tree.iterchildren()])
+
+
 def _turnToLxmlTree(xhtmlContent):
     if not xhtmlContent or not xhtmlContent.strip():
         return xhtmlContent
@@ -553,15 +599,19 @@ def separate_images(xhtmlContent, pretty_print=False):
         # only manage <p>/<div> containing several <img>, nothing else
         imgs = elt.xpath('.//img')
         len_imgs = len(imgs)
-        contained_tags = elt.getchildren()
-        if len_imgs > 1 and len_imgs == len(contained_tags) and not elt.text_content():
-            changed = True
-            for img_index, img in enumerate(imgs[1:]):
-                new_elt = lxml.html.Element(elt.tag)
-                tree.insert(elt_index + inserted_index + img_index, new_elt)
-                inserted_index += 1
-                # append will move the img, not necessary to remove from elt
-                new_elt.append(img)
+        if len_imgs > 1:
+            # <p> may not contain anything else than <img> or <br>
+            contained_tags = [child for child in elt.getchildren()
+                              if child.tag not in ('br', )]
+            # contained text, if <p> contains <img> and text, we can not separate it
+            if len_imgs == len(contained_tags) and not elt.text_content().strip():
+                changed = True
+                for img_index, img in enumerate(imgs[1:]):
+                    new_elt = lxml.html.Element(elt.tag)
+                    tree.insert(elt_index + inserted_index + img_index, new_elt)
+                    inserted_index += 1
+                    # append will move the img, not necessary to remove from elt
+                    new_elt.append(img)
 
     if not changed:
         return xhtmlContent
